@@ -1,7 +1,8 @@
 from .ac_qq_com import AcQqComCrypt
 from .base_lib import BaseLib
 from .kissmanga_com import KissMangaComCrypt
-from .manga_rock_com import MangaRockComCrypt
+from .mangarock_com import MangaRockComCrypt
 from .manhuagui_com import ManhuaGuiComCrypt
 from .puzzle import Puzzle
 from .sunday_webry_com import SundayWebryCom
+from .mangago_me import MangaGoMe
