@@ -5,6 +5,7 @@ from .url_normalizer import normalize_uri
 
 class Request:
     __redirect_base_url = ''
+    _headers = None
     referer = ''
     proxies = None
     allow_webp = True
@@ -17,12 +18,13 @@ class Request:
     default_lang = 'ru-RU,ru;q=0.8,en-US;q=0.5,en;q=0.3'
     cookies = None
     kwargs = None
-    _headers = None
-    debug = True
+    debug = False
+    _history = None
 
     def __init__(self):
         self.proxies = {}
         self.cookies = {}
+        self._history = []
 
     def __patch_headers(self, headers):
         if isinstance(self._headers, dict):
@@ -50,10 +52,10 @@ class Request:
 
     def __redirect_helper(self, r, url, method):
         proxy = None
+        location = url
         if r.status_code == 303:
             method = 'get'
-        if r.status_code == 305:
-            location = url
+        elif r.status_code == 305:
             proxy = {
                 'http': r.headers['location'],
                 'https': r.headers['location'],
@@ -80,7 +82,9 @@ class Request:
         self.__update_cookies(r)
         if r.is_redirect and method != 'head':
             if max_redirects < 1:
+                self.debug and print(self._history)
                 raise AttributeError('Too many redirects')
+            self._history.append(url)
             proxy, location, method = self.__redirect_helper(r, url, method)
             if proxy:
                 kwargs['proxies'] = proxy
@@ -102,6 +106,7 @@ class Request:
     ) -> requests.Response:
         if not isinstance(headers, dict):
             headers = {}
+        self._history = []
         cookies = self._get_cookies(cookies)
         headers.setdefault('User-Agent', self.user_agent)
         headers.setdefault('Referer', self.referer)
@@ -157,7 +162,6 @@ class Request:
         :param url:
         :return:
         """
-        session = requests.Session()
-        h = session.head(url)
-        session.close()
-        return h.cookies
+        response = self.requests(url=url, method='head')
+        response.close()
+        return response.cookies
