@@ -26,15 +26,17 @@ class Parser:
             log: callable = None,
             quest: callable = None,
             info: Info = None,
+            quest_password: callable = None,
     ):
         provider = get_provider(self.params.get('url', ''))
-        if not provider:
+        if isinstance(provider, bool):
             raise AttributeError('Provider not found')
         self.provider = provider(info)  # provider __init__
 
         self.provider.set_progress_callback(progress)
         self.provider.set_log_callback(log)
         self.provider.set_quest_callback(quest)
+        self.provider.set_quest_password_callback(quest_password)
 
     def start(self):
         self.provider.process(self.params['url'], self.params)
