@@ -10,6 +10,9 @@ providers_list = {
     'ac_qq_com': [
         r'ac\.qq\.com/Comic.+?/id/\d',
     ],
+    'acomics_ru': [
+        r'acomics\.ru/~.',
+    ],
     'adulto_seinagi_org': [
         r'adulto\.seinagi\.org/(series|read)/.',
         r'xanime-seduccion\.com/(series|read)/.',
@@ -49,6 +52,9 @@ providers_list = {
     'chochox_com': [
         r'chochox\.com/.',
     ],
+    'choutensei_260mb_net': [
+        r'choutensei\.260mb\.net/(series|read)/.',
+    ],
     'comicextra_com': [
         r'comicextra\.com/.',
     ],
@@ -62,7 +68,7 @@ providers_list = {
         r'comic\.webnewtype\.com/contents/.',
     ],
     'comico_jp': [
-        r'comico\.jp/(detail|articleList).+titleNo.',
+        r'comico\.jp(?:/challenge)?/(detail|articleList).+titleNo.',
     ],
     'comicsandmanga_ru': [
         r'comicsandmanga\.ru/online-reading/.',
@@ -139,10 +145,7 @@ providers_list = {
         r'hatigarmscans\.net/manga/.',
     ],
     'heavenmanga_biz': [
-        r'heavenmanga\.site/.',
-        r'heavenmanga\.world/.',
-        r'heavenmanga\.life/.',
-        r'heavenmanga\.biz/.',
+        r'heavenmanga\.\w+/.',
     ],
     'hentai2read_com': [
         r'hentai2read\.com/.',
@@ -582,6 +585,10 @@ providers_list = {
         r'digitalteamreader\.netsons\.org/(series|read)/.',
         r'reader\.manga-download\.org/(series|read)/.',
     ],
+    'readcomicbooksonline_org_manga': [
+        r'readcomicbooksonline\.net/manga/.',
+        r'readcomicbooksonline\.org/manga/.',
+    ],
     'readcomicbooksonline_org': [
         r'readcomicbooksonline\.net/.',
         r'readcomicbooksonline\.org/.',
@@ -610,6 +617,9 @@ providers_list = {
     'readms_net': [
         r'readms\.net/(r|manga)/.',
     ],
+    'remanga_org': [
+        r'remanga\.org/manga/.',
+    ],
     'santosfansub_com': [
         r'santosfansub\.com/Slide/.',
     ],
