@@ -4,15 +4,12 @@ from .helpers.std import Std
 
 class BatoTo(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name([
+    def get_chapter_index(self) -> str:
+        return '-'.join([
             self.chapter_id,
             self.chapter[1]
         ])
 
-    def get_chapter_index(self) -> str:
-        return self.re.search(r'/chapter/(\d+)', self.chapter[0]).group(1)
-
     def get_main_content(self):
         url = self.get_url()
         if ~url.find('/chapter/'):
