@@ -31,5 +31,8 @@ class DoujinsCom(Provider, Std):
         # todo meta
         pass
 
+    def chapter_for_json(self):
+        return self.get_url()
+
 
 main = DoujinsCom
