@@ -5,8 +5,17 @@ from .helpers.std import Std
 class MangaFoxMe(Provider, Std):
 
     def get_archive_name(self) -> str:
-        idx = self.get_chapter_index().split('-')
-        return self.normal_arc_name(idx)
+        groups = self._ch_parser()
+        ch = groups[1].replace('.', '-')
+        vol = '0'
+        if groups[0]:
+            vol = groups[0]
+        return self.normal_arc_name({'vol': vol, 'ch': ch})
+
+    def _ch_parser(self):
+        selector = r'/manga/[^/]+/(?:(v[^/]+)/)?c([^/]+)/'
+        groups = self.re.search(selector, self.chapter).groups()
+        return groups
 
     def get_chapter_index(self) -> str:
         """
@@ -23,8 +32,7 @@ class MangaFoxMe(Provider, Std):
         <domain>/manga/<name>/v03/c020.5/1.html
         <domain>/manga/<name>/v08/c031/1.html
         """
-        selector = r'/manga/[^/]+/(?:(v[^/]+)/)?c([^/]+)/'
-        groups = self.re.search(selector, self.chapter).groups()
+        groups = self._ch_parser()
         idx = groups[1].replace('.', '-')
         if not ~idx.find('-'):
             idx = idx + '-0'
