@@ -43,5 +43,8 @@ class FreeAdultComixCom(Provider, Std):
         # todo meta
         pass
 
+    def chapter_for_json(self):
+        return self.get_url()
+
 
 main = FreeAdultComixCom
