@@ -4,9 +4,6 @@ from .helpers.std import Std
 
 class FreeMangaTo(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index().split('-'))
-
     def get_chapter_index(self) -> str:
         re = self.re.compile(r'[Cc]hapter\s(\d+(?:\.\d+)?)')
         chapter = re.search(self.chapter[0]).group(1)
