@@ -2,6 +2,9 @@ from ._http2 import Http2
 
 
 class Std:
+    def get_archive_name(self) -> str:
+        return self.normal_arc_name({'vol': self.get_chapter_index().split('-')})
+
     def _elements(self, selector, content=None) -> list:
         if not content:
             content = self.content
@@ -9,7 +12,7 @@ class Std:
 
     def _cover_from_content(self, selector, attr='src') -> str:
         image = self._elements(selector)
-        if image and len(image):
+        if image is not None and len(image):
             return self.http().normalize_uri(image[0].get(attr))
 
     @staticmethod
@@ -76,9 +79,22 @@ class Std:
         return name
 
     def normal_arc_name(self, idx):
-        fmt = 'vol_{:0>3}'
-        if not isinstance(idx, list):
+        if isinstance(idx, str):
             idx = [idx]
+        if isinstance(idx, list):
+            return self.__normal_name_list(idx)
+        if isinstance(idx, dict):
+            return self.__normal_name_dict(idx)
+        raise DeprecationWarning('Wrong arc name type: %s' % type(idx))
+
+    @staticmethod
+    def __fill(var, fmt: str = '-{}'):
+        if len(var) > 1:
+            var = (fmt * len(var)).format(*var)
+        return var
+
+    def __normal_name_list(self, idx: list):
+        fmt = 'vol_{:0>3}'
         if len(idx) > 1:
             fmt += '-{}' * (len(idx) - 1)
         elif self._zero_fill:
@@ -86,6 +102,19 @@ class Std:
             fmt += '-{}'
         return fmt.format(*idx)
 
+    def __normal_name_dict(self, idx: dict):
+        vol = idx.get('vol', '0')
+        ch = idx.get('ch', None)
+        fmt = 'vol{}'
+        data = [self.__fill(vol, '-{:0>3}')]
+        if ch:
+            fmt += '-ch{}'
+            data.append(self.__fill(ch))
+        result = fmt.format(*data)
+        if self._with_manga_name:
+            result = '%s-%s' % (self.manga_name, result)
+        return result
+
     def text_content(self, content, selector, idx: int = 0, strip: bool = True):
         doc = self.document_fromstring(content, selector)
         if not doc:
