@@ -45,5 +45,8 @@ class HentaiImageCom(Provider, Std):
         # todo meta
         pass
 
+    def chapter_for_json(self):
+        return self.get_url()
+
 
 main = HentaiImageCom
