@@ -3,6 +3,8 @@ from manga_py.fs import basename
 from manga_py.provider import Provider
 from .helpers.std import Std
 
+from sys import stderr
+
 
 class KissMangaCom(Provider, Std):
     __local_data = {
@@ -24,8 +26,12 @@ class KissMangaCom(Provider, Std):
         if name:
             name = name.groups()
             return '{1}-{0}-0'.format(*name)
-        name = self.re.search(r'Ch\w*?-(\d+)(?:-v(\d+))?', bn).groups()
-        return '{}-{}-0'.format(*name, '0')
+        name = self.re.search(r'Ch\w*?-(\d+)(?:-v(\d+))?', bn)
+        if name:
+            name = name.groups()
+            return '{}-{}-0'.format(*name, '0')
+        name = self.re.search(r'/Manga/[^/]+/(\d+)', self.chapter)
+        return '{}-000-0'.format(name.group(1))
 
     def get_main_content(self):
         return self._get_content('{}/Manga/{}')
@@ -34,18 +40,27 @@ class KissMangaCom(Provider, Std):
         return self._get_name('/Manga/([^/]+)')
 
     def get_chapters(self):
-        return self._elements('.listing td a')
+        chapters = self._elements('.listing td a')
+        if not len(chapters):
+            print('Chapters not found', file=stderr)
+        return chapters
 
     def prepare_cookies(self):
+        self._params['rename_pages'] = True
         self.cf_protect(self.get_url())
         self._storage['cookies']['rco_quality'] = 'hq'
+        if not self._params['cf-protect']:
+            print('CloudFlare protect fail!', file=stderr)
 
     def __decrypt_images(self, crypt, key, hexes):
         images = []
         for i in hexes:
-            img = crypt.decrypt(self.__local_data['iv'], key, i)
-            img = img.decode('utf-8').replace('\x10', '').replace('\x0f', '')
-            images.append(img)
+            try:
+                img = crypt.decrypt(self.__local_data['iv'], key, i)
+                images.append(img.decode('utf-8', errors='ignore').replace('\x10', '').replace('\x0f', ''))
+
+            except Exception as e:
+                pass
 
         return images
 
@@ -65,17 +80,13 @@ class KissMangaCom(Provider, Std):
 
     def get_files(self):
         crypt = KissMangaComCrypt()
-
         content = self.http_get(self.chapter)
         key = self.__check_key(crypt, content)
-
         hexes = self.re.findall(r'lstImages.push\(wrapKA\(["\']([^"\']+?)["\']\)', content)
-
         if not hexes:
+            print('Images not found!', file=stderr)
             return []
-
         self._storage['referer'] = self.http().referer = ''
-
         return self.__decrypt_images(crypt, key, hexes)
 
     def get_cover(self):
