@@ -4,9 +4,6 @@ from .helpers.std import Std
 
 class MangaAe(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index())
-
     def get_chapter_index(self) -> str:
         return self.re.search(r'\.ae/[^/]+/(\d+)', self.chapter).group(1)
 
