@@ -7,10 +7,6 @@ class MangaSh(Provider, Std):
     _cdn_url = 'https://cdn.manga.sh/'
     __local_storage = None
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index().split('-')
-        return self.normal_arc_name(idx)
-
     def get_chapter_index(self) -> str:
         chapter = self.chapter
         _ch = chapter.get('ChapterNumberAbsolute', self.chapter_id)
