@@ -5,9 +5,6 @@ from .helpers.std import Std
 class MangaBoxMe(Provider, Std):
     _local_storage = False
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self._storage['current_chapter'])
-
     def get_chapter_index(self) -> str:
         return self.re.search(r'/episodes/(\d+)', self.chapter).group(1)
 
