@@ -4,9 +4,6 @@ from .helpers.std import Std
 
 class MangaHasuSe(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index().split('-'))
-
     def get_chapter_index(self) -> str:
         re = self.re.compile('chapter-+(\d+)(?:-+(\d+))?')
         idx = re.search(self.chapter).groups()
