@@ -5,9 +5,6 @@ from .helpers.std import Std
 class MangaKatanaCom(Provider, Std):
     name_re = r'/manga/([^/]+)'
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index().split('-'))
-
     def get_chapter_index(self) -> str:
         re = self.re.compile(r'/manga/.+?\d/c(\d+(?:\.\d)?(?:-v\d)?)')
         return re.search(self.chapter).group(1).replace('.', '-')
