@@ -5,10 +5,6 @@ from .helpers.std import Std
 class MangaLifeUs(Provider, Std):
     img_selector = '.image-container .CurImage'
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index().split('-')
-        return self.normal_arc_name(idx)
-
     def get_chapter_index(self) -> str:
         selector = r'-chapter-(\d+).+-index-(\d+)'
         chapter = self.re.search(selector, self.chapter)
