@@ -5,13 +5,9 @@ from .helpers.std import Std
 class MangaOnlineToday(Provider, Std):
     _img_selector = '#sct_content img'
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index().split('.')
-        return self.normal_arc_name(idx)
-
     def get_chapter_index(self) -> str:
         idx = self.re.search(r'\.today/[^/]+/([^/]+)', self.chapter)
-        return idx.group(1)
+        return idx.group(1).replace('.', '-')
 
     def get_main_content(self):
         return self._get_content('{}/{}/')
