@@ -9,9 +9,6 @@ class MangaRockCom(Provider, Std):
     crypt = None
     __api_uri = 'https://api.mangarockhd.com/query/web400/'
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index())
-
     def get_chapter_index(self) -> str:
         return str(self.chapter_id)
 
@@ -30,7 +27,7 @@ class MangaRockCom(Provider, Std):
         idx = self._get_name('/manga/([^/]+)')
         url = '{}info?oid={}&last=0&country=Japan'.format(self.__api_uri, idx)
         items = self.json.loads(self.http_get(url))
-        return [(i.get('oid'),) for i in items.get('data', {}).get('chapters', [])]
+        return [(i.get('oid'),) for i in items.get('data', {}).get('chapters', [])][::-1]
 
     def __get_url(self):
         return '{}pages?oid={}&country=Japan'.format(self.__api_uri, self.chapter[0])
