@@ -4,10 +4,6 @@ from .helpers.std import Std
 
 class MangaSupaCom(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index().split('-')
-        return self.normal_arc_name(idx)
-
     def get_chapter_index(self) -> str:
         idx = self.re.search('/chapter_([^/]+)', self.chapter)
         return '-'.join(idx.group(1).split('.'))
