@@ -4,9 +4,6 @@ from .helpers.std import Std, Http2
 
 class MyMangaListOrg(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index())
-
     def get_chapter_index(self) -> str:
         # re = self.re.compile(r'/chapter-[^/]+-(\d+)')
         re = self.re.compile(r'/download/[^/]+?(\d+)')
