@@ -3,9 +3,6 @@ from .helpers.std import Std
 
 
 class MyReadingMangaInfo(Provider, Std):
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index()
-        return self.normal_arc_name(idx)
 
     def get_chapter_index(self, no_increment=False) -> str:
         return str(self.chapter_id)
