@@ -35,5 +35,8 @@ class PornComixInfo(Provider, Std):
         # todo meta
         pass
 
+    def chapter_for_json(self):
+        return self.get_url()
+
 
 main = PornComixInfo
